////////////////////////////////////////////////////////////////////////////////////////
// f_compare_addfile_4.js
// 
// Functional test
// 	Using addFile() method, installs file regardless of baseline registry version.
//	Jar source files will be installed under certain 'update' conditions described below.
//	This should allow for a quick visual check in the logfile, on the hard drive, and in
//	the registry. Installation labels should be easy to identify.
//
//	This will test the addFile() accepting 4 parameters (no version parameter):
//	addFile(String regName, String jarSrc, Install object f, String jarSrc).
//
// 	There are 4 main sets of tests: comparing major, minor, release and build components
//	of the input version and registry string. In each set, there are 2 tests: one with
//	a larger input component and the other with a smaller one than the corresponding
//	reg component. In addition to these 8 tests, there will be one more where the input
//	and registry versions are the same.
//
//	A directory called "f_compare_addfile_4" will be created in the executable
//	folder. The 9 original jar source files (smrtupdt#.txt) will be dumped in this
//	directory. All 9 files should be installed in a subdirectory called "updated".
//	This indicates that addFile() worked correctly and installed the files.
//	For each of these 9 cases, a separate registry node will be created. 
//
// ~ XPInstall QA
//   January 17, 2000. David Epstein. Created. 
//   February 15, 2000. David Epstein. Updated. 
//   March 31, 2000. David Epstein. Renamed API.
//
////////////////////////////////////////////////////////////////////////////////////////

var regStart = "compare_addfile_4";
var regName = "f_compare_addfile_4";
var vi = "10.10.10.10";
var jarSrc = "smrtupdt";
var folderName = "f_compare_addfile_4";

// *********************************************************************************

// function addFileNoVers4 (no version string accepted into addfile()):
// Installs a file and input version for all cases.

function addFileNoVers4(versionString, folderName, regName, jarSrc)
{
   doInstall_addfile_4(versionString, folderName, regName, jarSrc);

   var realReg = regStart + "/" + regName;
   returnVersion = InstallTrigger.getVersion(realReg);
   logComment("the installed version = " + returnVersion);
}

// *********************************************************************************

// function doInstall_addfile_4.
// Simply installs a new file in a designated folder.

function doInstall_addfile_4(versionString, folderName, regName, jarSrc)
{
   initInstall("addFileNoVers4", regStart, versionString, 0);
   f = getFolder("Program", folderName);
   addFile(regName, jarSrc, f, jarSrc); // 4 parameter form of addFile()

   if (0 == getLastError())
      performInstall();
   else
      cancelInstall(); 
}

// *********************************************************************************

// function fileTestsNoVers4
// Loops through all cases, comparing input and registry versions. Calls addFileNoVers4.
// There are 9 cases comparing the different components of version strings in the
// form of "major.minor.release.build":
// a) comparing major components, input is greater than registry.
// b) comparing major components, input is less than registry.
// c) comparing minor components, input is greater than registry.
// d) comparing minor components, input is less than registry.
// e) comparing release components, input is greater than registry.
// f) comparing release components, input is less than registry.
// g) comparing build components, input is greater than registry.
// h) comparing build components, input is less than registry.
// i) input and registry versions are the same.

function fileTestsNoVers4(vi, folderName, regName, jarSrc)
{
   for (var i = 1; i <= 9; i++)
   {
      var localSrc = jarSrc + i + ".txt";
      var localReg = regName + i;
      var localFolder = folderName + "/updated";

      doInstall_addfile_4(vi, folderName, localReg, localSrc);  // reset the registry
      switch(i)
      {
      case 1:		// input major is greater than registry major
         addFileNoVers4("11.10.10.10", localFolder, localReg, localSrc);
         break;
      case 2:		// input major is less than registry major
         addFileNoVers4("9.10.10.10", localFolder, localReg, localSrc);      
         break;
      case 3:		// input minor is greater than registry minor
         addFileNoVers4("10.11.10.10", localFolder, localReg, localSrc);
         break;
      case 4:		// input minor is less than registry minor
         addFileNoVers4("10.9.10.10", localFolder, localReg, localSrc);
         break;
      case 5:           // input release is greater than registry release
         addFileNoVers4("10.10.11.10", localFolder, localReg, localSrc);
	 break;
      case 6:		// input release is less than registry release
         addFileNoVers4("10.10.9.10", localFolder, localReg, localSrc);
	 break;
      case 7:		// input build is greater than registry build
         addFileNoVers4("10.10.10.11", localFolder, localReg, localSrc);
	 break;
      case 8:		// input build is less than registry build
         addFileNoVers4("10.10.10.9", localFolder, localReg, localSrc);
	 break;
      case 9:		// input version is the same as registry version
         addFileNoVers4("10.10.10.9", localFolder, localReg, localSrc);
	 break;
      default:
         logComment("There was a problem with 'for' loop execution.");
         break;
      } 	// end switch statement
   }		// end for loop
}

// *********************************************************************************

//	Begin Main script

logComment("Begin script.");

fileTestsNoVers4(vi, folderName, regName, jarSrc);

logComment("End script.");


// *********************************************************************************


